#!/usr/bin/env python3
# coding: utf-8

#!/usr/bin/python3
# -*- coding: utf-8 -*-

"""
user registration

author: dell author
last edited: Feb 2019
"""
import os
import json
import logging
import requests

from DellLinuxAssistant.telemetry.dbus_helper import DbusHandler
from DellLinuxAssistant.telemetry.file_helper import FileHelper
from DellLinuxAssistant.telemetry.profile_helper import conf
from DellLinuxAssistant.telemetry.telemetry_common import Struct

class MyDellRegistration(object):

    def __init__(self):

        self._running = True
        self.dbus_handler = DbusHandler()
        self.file_helper = FileHelper()

    def SetRegistrationEvent(self, st):
        """
        set Registration value
        :param st: registration status
        :return:
        """
        directory = os.path.expanduser('~') + '/'+ conf['AppFolderPath']
        config_dir = os.path.join(directory, conf['AppFileName'])
        if not os.path.exists(directory):
            os.makedirs(directory)

        self.file_helper.UpdateEventFile({'IS_REGISTERED': st}, config_dir)


    def GetRegistrationEvent(self):
        """
        get registration value
        :param value: True or False
        :return:
        """
        config_dir = os.path.join(os.path.expanduser('~'), conf['AppFolderPath'], conf['AppFileName'])
        data = FileHelper().GetDataFromFile(config_dir, True)
        return (data.get('IS_REGISTERED') or False) if data else False

    def DoRegistration(self, formData, email, jsonFormData, serviceTag):
        """
        Method to registration
        :param formData:
        :param email:
        :param jsonFormData:
        :param serviceTag:
        :return:
        """
        try:
            _output = self.dbus_handler.backend().get_library_info("GetSystemProfile", "{}")
            if _output == 'unknow':
                return False
            systemProfile = Struct(**(json.loads(_output)))

            self.dbus_handler.LogComplexEvent("Registration - BIL - Comp", jsonFormData)
            SumInput = systemProfile.appSecret + "|" + email + "|" + serviceTag

            _input = json.dumps({'SumInput': SumInput})
            _hash = self.dbus_handler.backend().get_library_info('getSumInput', _input)
            if _hash == 'unknow' :
                return False

        except Exception as msg:
            self.dbus_handler.dbus_massage("[LIBRARY Info] error: "+ str(msg))
            return False

        formData += "&CKSM=" + _hash
        isSuccessful = self.ProcessBILRequestResponse(formData, systemProfile)

        return isSuccessful

    def ProcessBILRequestResponse(self, formData, systemProfile):
        """
        Method to bil request
        :param formData:
        :param systemProfile:
        :return:
        """
        try:
            serviceTag = self.dbus_handler.backend().get_HW_info()[0]

            _input = json.dumps({'url_name': 'Bil_Prod_Url'})
            url = self.dbus_handler.backend().get_library_info('GetRegistrationUrl', _input) \
                  + systemProfile.appKey + "&SRNM=" + serviceTag
            if url == 'unknow':
                return False

            is_production = True
            _input = json.dumps({'is_product': is_production})
            authInfo = self.dbus_handler.backend().get_library_info('getAuthInfo', _input)
            if authInfo == 'unknow':
                return False

        except Exception as msg:
            self.dbus_handler.dbus_massage(msg)
            return False

        try:

            data = formData
            response = requests.post(url,
                              data = data,
                              headers={
                                  'Authorization': 'Basic {0}'.format(authInfo),
                                  'content-type': 'application/x-www-form-urlencoded; charset=utf-8'
                              }, timeout=5)

            msg = response.json()
            if msg:
                if msg['status'] == 'ok':
                    self.dbus_handler.logMetricEvent("Registration - BIL", "Success")
                    return True
                else:
                    self.dbus_handler.logMetricEvent("Registration - BIL", "Fail")

            else:
                self.dbus_handler.logMetricEvent("Registration - BIL", "Fail")

        except Exception as err:
            logging.error("[Registration - BIL], error: {}".format(str(err)))
            self.dbus_handler.logMetricEvent("Registration - BIL", "Fail")

        return False

    def SetWebAppVersion(self, webAppVer):
        """
        Method to set app version
        :param webAppVer: version number
        :return:
        """

        if webAppVer is None:
            self.webAppVersion = webAppVer
            return True

        return False

    def string_dict(self, sstr):

        data = {}
        new_list = sstr.split('&')
        for item in new_list:
            tmp = item.split('=')
            data[tmp[0]] = tmp[1]

        return data


def async_function(generator):
    """
    Because the generator/coroutine will raise a StopIteration exception when it returns normal,
    and the original return value is stored in the value
    property of the StopIteration object, the actual return value of the coroutine can be obtained by capturing this
    :param generator: generator
    :return:
    """
    try:
        generator.send(None)
    except StopIteration as res:
        return res.value


if __name__ == "__main__":
    registration = MyDellRegistration()
