#!/usr/bin/env python3
# coding: utf-8

"""
create account class

Environment: ubuntu 18.04
Author: Dell Author
Last edited: February 2019

"""
import json
import requests

from urllib import parse
from DellLinuxAssistant.telemetry.dbus_helper import DbusHandler
from DellLinuxAssistant.telemetry.telemetry_common import Struct


class IdmRepository(object):
    """create account """

    def __init__(self):
        self.dbus_handler = DbusHandler()

    def TryCreateAccount(self, jsonData):
        """
        :param jsonData: jsonData
        :return:
        """
        if not jsonData:
            return False

        userDetails = {}
        dataArray = parse.unquote(jsonData).split('&')
        for item in dataArray:

            if item.find("FNAM") == 0:
                userDetails['FirstName'] = self.GetValue(item)

            elif item.find("LNAM") == 0:
                userDetails['LastName'] = self.GetValue(item)

            elif item.find("EMAL") == 0:
                userDetails['Email'] = self.GetValue(item).replace('%40', '')

        _output = self.dbus_handler.backend().get_library_info("GetSystemProfile", "{}")
        if _output == 'unknow':
            return False
        regConfig = Struct(**(json.loads(_output)))

        sysProfile = self.dbus_handler.backend().get_HW_info()
        allProfile = str(sysProfile[11])
        osLanguage = allProfile[:allProfile.index('.')]
        country = osLanguage[osLanguage.index('_')+1:]
        parameterValue = "connID==={0}ANDfname==={1}ANDlname==={2}ANDemail==={3}" \
                         "ANDsvtag==={4}ANDc==={5}ANDl==={6}".format(
                        regConfig.IDMConnectionID,
                        userDetails.get('FirstName', ''),
                        userDetails.get('LastName', ''),
                        userDetails.get('Email', ''),
                        str(sysProfile[0]),
                        country,
                        osLanguage.split('_')[0])

        try:
            inputs = json.dumps({'parameterValue': parameterValue,
                                 'IDMHashKey': regConfig.IDMHashKey})
            encryptedValue = self.dbus_handler.backend().get_library_info('getIdentityContent', inputs)
        except Exception as err:
            print("[getIdentityContent] err: ", str(err))
            return False

        values = {"Value": encryptedValue}

        url = regConfig.IDMBaseUrl + "/api/account/createaccount"
        try:
            response = requests.post(url,
                                     data=values,
                                      headers={
                                          'content-type': 'application/x-www-form-urlencoded; charset=utf-8'
                                      },
                                     timeout=5)

            if response.status_code == 200:
                self.dbus_handler.logMetricEvent("Idm-Response", str(response.content))
                return True
            else:
                self.dbus_handler.logMetricEvent("Idm-Response", str(response.status_code))
        except Exception as err:
            self.dbus_handler.logMetricEvent("Idm-Exception", str(err))

        return False

    def GetValue(self, property):
        """
        key=value, get value
        :param property: key=value
        :return: value
        """
        startIndex = property.index('=') + 1
        return property[startIndex:]


def async_function(generator):
    """
    Because the generator/coroutine will raise a StopIteration exception when it returns normal,
    and the original return value is stored in the value
    property of the StopIteration object, the actual return value of the coroutine can be obtained by capturing this
    :param generator: generator
    :return:
    """
    try:
        generator.send(None)
    except StopIteration as res:
        return res.value

if __name__ == '__main__':

    idm = IdmRepository()

