#!/usr/bin/env python
# -*- coding:utf-8 -*-

import json
import os
import logging
from DellLinuxAssistant.telemetry.telemetry_common import read_sys_data


def get_os_language():
    """
    Get current OS language which supported by server side
    note: return 'en-US' ad default/Rest of the world
    """
    language_code = 'en-US'

    linux_lang_code = 'en_US'
    # get the OS environment variables
    OS_env = os.environ
    if "LANG" in OS_env.keys():
        linux_lang_code = OS_env["LANG"]

    # convert language code
    # linux language code e.g.: gez_ET@abegede, gl_ES.UTF-8, 
    code_tmp = linux_lang_code.strip().split(' ')[0].split('.')[0].split('@')[0]

    # mapping language code to the name which supported by server side
    # some special cases fir Chinese language
    if code_tmp in ('zh_CN', 'zh_SG'):
        language_code = 'zh-hans'
    elif code_tmp in ('zh_TW', 'zh_HK'):
        language_code = 'zh-hant'
    # for others, replace '_' with '-'
    else:
        # convert language code to server supported
        language_code = code_tmp.replace('_', '-')

    return language_code


def get_os_country():
    """
    Get current OS country which supported by server side
    note: return 'US' as default/ Rest of the world
    """
    country_code = 'US'
    try:
        # get geo id
        with open("/usr/share/dell-linux-assistant/TZ_L2W.dat") as f:
            json_data = f.read()
            U2W = json.loads(json_data)
            path = "/etc/timezone"
            geoid = U2W[read_sys_data(path).decode()]

        # parse geoid to country name struct, and get short name
        with open("/usr/share/dell-linux-assistant/registration/jsons/Geo2CY.json") as f:
            json_data = f.read()
            json_country = json.loads(json_data)
            country_detail = json_country[str(geoid)]
            country_short_name = country_detail['short_name']

        # mapping country short name to country Two letter ISO code
        # which supported by server side
        with open("/usr/share/dell-linux-assistant/registration/jsons/CountryList.json", encoding="ISO-8859-1") as f:
            json_data = f.read()
            json_country_code = json.loads(json_data)
            for country_item in json_country_code:
                if country_short_name == country_item.get('Name'):
                    # will get None if short name not match
                    country_code = country_item.get('TwoLetterIsoCode')
        # if no matching country ISO code found, return default code
        if not country_code:
            country_code = 'US'
        return country_code
    except Exception as e:
        return country_code
