import gi
import os
import sys
import time

gi.require_version('Notify', '0.7')
from gi.repository import Notify

from DellLinuxAssistant.telemetry.file_helper import FileHelper
from DellLinuxAssistant.telemetry.profile_helper import conf


class RegistrationReminder(object):
    """
    User Registration Reminder class for each user
    """

    def __init__(self):
        self.file_helper = FileHelper()

    def notify(self):
        """
        Check user register status and send notify to unregistered user for 3 times
        Otherwise, exit when user registered or notify more than 3 times.
        For each user, all data records saved under user's home directory
        """
        # check register status and time notified
        # if user registered, then exit
        directory = os.path.expanduser('~') + '/'+ conf['AppFolderPath']
        if not os.path.exists(directory):
            os.makedirs(directory)

        registration_log_file = os.path.join(directory, conf['AppFileName'])
        data = self.file_helper.GetDataFromFile(registration_log_file, True)
        registered = (data.get('IS_REGISTERED') or False) if data else False

        if registered:
            sys.exit(0)

        # if notify more then 3 times, then exit
        reminder_log_file = os.path.join(directory, conf['ReminderFileName'])
        data = self.file_helper.GetDataFromFile(reminder_log_file, True)
        current_notify_count = (data.get('REMIND_TIMES') or 0) if data else 0
        if current_notify_count >= 3:
           sys.exit(0)

        app_icon = "/usr/share/pixmaps/dell-linux-assistant.svg"

        Notify.init("Dell Linux Assistant")
        
        # Create the notification object and show once
        notification = Notify.Notification.new(
            "Application dell-linux-assistant",
            "Register your Dell Account and improve your support experience",
            app_icon,
            )

        #notification.add_action(
        #    "action_click",
        #    "Let's Get You Registered!",
        #    notification_click,
        #    None
        #)
        # set urgency as normal (URGENCY_LOW, URGENCY_NORMAL, URGENCY_CRITICAL) = list(range(3))
        notification.set_urgency(1)
        # show notify after 5 min
        time.sleep(300)
        notification.show()

        # count of remind +1
        current_notify_count += 1
        self.file_helper.UpdateEventFile({'REMIND_TIMES': current_notify_count}, reminder_log_file)
        # process terminate
        sys.exit(0)
