#!/usr/bin/env python3
# coding: utf-8

#!/usr/bin/python3
# -*- coding: utf-8 -*-

"""
wechat repository

author: dell author
last edited: Feb 2019
"""
import json
import time
import random
import requests

from DellLinuxAssistant.telemetry.telemetry_common import ObjectThread
from DellLinuxAssistant.telemetry.dbus_helper import DbusHandler


class WeChatRepository(object):

    def __init__(self, serviceTag, lob, apiUrl, apiKey):
        self.baseApiUri = None
        self.apiKey = None

        self.lob = lob
        self.sncode = serviceTag
        self.apiKey = self.apiKey or apiKey
        self.baseApiUri = self.baseApiUri or apiUrl

        self.dbus_handler = DbusHandler()

    def Nonce(self):
        """
        random number
        :return: random
        """
        return str(random.randint(1, 2000 * 1000 * 1000))

    def UnixTimestamp(self):
        """
        Gets the unix timestamp
        :return:
        """
        total_second = int(time.time())

        return total_second

    def CheckWechatFollowingFromWeb(self):
        """
        request wechat server
        :return: bool
        """
        nounce = self.Nonce()
        timestamp = self.UnixTimestamp()

        try:
            inputs = json.dumps({'apiKey': self.apiKey,
                           'nounce': nounce,
                           'timestamp': self.UnixTimestamp()})
            signature = self.dbus_handler.backend().get_library_info('GenerateSignature', inputs)
        except Exception as err:
            print("[GenerateSignature] err: ", str(err))
            return False

        return self.RequestWechatFollowingFromWeb(nounce, timestamp, signature)

    @ObjectThread()
    def RequestWechatFollowingFromWeb(self, nounce, timestamp, signature):
        """
        request wechat server
        :param nounce: nounce number
        :param timestamp: time
        :param signature: sign
        :return:
        """
        api = "ks.php?model={0}&timestamp={1}&nonce={2}&signature={3}".format(self.lob,
                                                                              timestamp,
                                                                              nounce,
                                                                              signature)
        url = self.baseApiUri + api
        try:
            response = requests.post(url,
                                     data={
                                         'sncode': signature
                                     },
                                     timeout=3)
            msg = response.json()
            if msg:
                if msg['errcode'] == 0 and msg.get('data') and str(msg['data']['is_fans']) == "1":
                    print("Response for WeChat Follow Check Received: IsFans=1")
                    return True
                else:
                    print("Response for WeChat Follow Check Received: Error")

        except Exception as err:
            print("{0} WeChat Follow Check Exception caught.".format(err))

        return False

